How to use the twitchat bot
====================================

The twitchat chat bot will run on your own machine and allow you to run
more complex commands than other Twitch bots.


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   usage/quickstart
   usage/commands


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
